interface Cache {
    get(key: string): Promise<string>;
    set(key: string, value: string): Promise<void>;
}
interface Options {
    /**
     * Initial cache that will contain resolved dependencies.
     * `vue` must initially be contained in this object.
     *
     * **example:**
     * ```javascript
     *	...
     *	moduleCache: {
     *		vue: Vue,
     *	},
     *	...
     * ```
     *
    */
    moduleCache: Record<string, Module>;
    /**
     * Called by the library when it needs a file.
     * @param path  The path of the file
     * @returns a Promise of the file content (UTF-8)
     *
     * **example:**
     * ```javascript
     *	...
     *	getFile(url) {
     *
     *		return fetch(url).then(response => response.ok ? response.text() : Promise.reject(response));
     *	},
     *	...
     * ```
    */
    getFile(path: string): Promise<string>;
    /**
     * Called by the library when CSS style must be added in the HTML document.
     * @param style The CSS style chunk
     * @param scopeId The scope ID of the CSS style chunk
     * @return
     *
     * **example:**
     * ```javascript
     *	...
     *	addStyle(styleStr) {
     *
     *		const style = document.createElement('style');
     *		style.textContent = styleStr;
     *		const ref = document.head.getElementsByTagName('style')[0] || null;
     *		document.head.insertBefore(style, ref);
     *	},
     *	...
     * ```
    */
    addStyle(style: string, scopeId: string): void;
    /**
     * Additional babel plugins. [TBD]
     *
     *	```javascript
     *		...
     *		...
     *	```
    */
    additionalBabelPlugins?: any[];
    /**
     * Additional module type handlers. see [[ModuleHandler]]
     *
    */
    additionalModuleHandlers?: Record<string, ModuleHandler>;
    /**
     * [[get]]() and [[set]]() functions of this object are called when the lib needs to save or load already compiled code. get and set functions must return a `Promise` (or can be `async`).
     * Since compilation consume a lot of CPU, is is always a good idea to provide this object.
     *
     * **example:**
     *
     * In the following example, we cache the compiled code in the browser's local storage. Note that local storage is a limited place (usually 5MB).
     * Here we handle space limitation in a very basic way.
     * Maybe (not tested), the following lib may help you to gain more space [pako](https://github.com/nodeca/pako)
     * ```javascript
     *	...
     *	compiledCache: {
     *		set(key, str) {
     *
     *			// naive storage space management
     *			for (;;) {
     *
     *				try {
     *
     *					// doc: https://developer.mozilla.org/en-US/docs/Web/API/Storage
     *					window.localStorage.setItem(key, str);
     *					break;
     *				} catch(ex) { // handle: Uncaught DOMException: Failed to execute 'setItem' on 'Storage': Setting the value of 'XXX' exceeded the quota
     *
     *					window.localStorage.removeItem(window.localStorage.key(0));
     *				}
     *			}
     *		},
     *		get(key) {
     *
     *			return window.localStorage.getItem(key);
     *		},
     *	},
     *	...
     * ```
     */
    compiledCache?: Cache;
    /**
     * Called by the library when there is somthing to log (eg. scripts compilation errors, template compilation errors, template compilation  tips, style compilation errors, ...)
     * @param type the type of the notification, it respects console property names (error, warn, info).
     * @param args the values to log
     * @return
     *
     * ```javascript
     *	...
     *	log(type, ...args) {
     *
     *		console.log(type, ...args);
     *	},
     *	...
     * ```
     */
    log?(type: string, ...data: any[]): void;
}
/**
 * This just represents a loaded js module
 */
interface Module {
}
/**
 * Used by the library when it does not know how to handle a given file type (eg. `.json` files).
 * see [[additionalModuleHandlers]]
 * @param source The content of the file
 * @param path The path of the file
 * @param options The options
 *
 * **example:**
 *
 * ```javascript
 *	...
 *	additionalModuleHandlers: {
 *		'.json': (source, path, options) => JSON.parse(source),
 *	}
 *	...
 * ```
 */
interface ModuleHandler {
    (source: string, path: string, options: Options): Promise<Module>;
}
/**
 * the version of the library (process.env.VERSION is set by webpack, at compile-time)
 */
export declare const version: string;
/**
 * This is the main function.
 * @param path  The path of the .vue file
 * @param options  The options
 * @returns A Promise of the component
 *
 * **example using `Vue.defineAsyncComponent`:**
 * ```javascript
 *
 *	const app = Vue.createApp({
 *		components: {
 *			'my-component': Vue.defineAsyncComponent( () => loadModule('./myComponent.vue', options) )
 *		},
 *		template: '<my-component></my-component>'
 *	});
 *
 * ```
 *
 * **example using await:**
 * _the following code requires to be placed in an async function_
 *
 * ```javascript
 *
 *	const app = Vue.createApp({
 *		components: {
 *			'my-component': await loadModule('./myComponent.vue', options)
 *		},
 *		template: '<my-component></my-component>'
 *	});
 *
 * ```
 *
 */
export declare function loadModule(path: string, options?: Options): Promise<Module>;
export {};
